"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebAddressesRows = exports.getOrganizationCanonicalUrl = exports.getOrganizationNameBasedUrl = void 0;
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var lodash_1 = require("lodash");
var getOrganizationNameBasedUrl = function (solution, organization) {
    var orgHasItsOwnSubDomain = (0, primeobjects_helper_util_1.isNonEmptyString)(organization.subdomain);
    var subdomain = orgHasItsOwnSubDomain
        ? organization.subdomain
        : organization.slug;
    return "https://".concat(subdomain, ".").concat(solution.domain, "/");
};
exports.getOrganizationNameBasedUrl = getOrganizationNameBasedUrl;
var getOrganizationCanonicalUrl = function (solution, organization) {
    return "https://o-".concat(organization.shortId, ".").concat(solution.domain, "/");
};
exports.getOrganizationCanonicalUrl = getOrganizationCanonicalUrl;
var getWebAddressesRows = function (props) {
    var _a, _b;
    var sectionLine = props.sectionLine, solution = props.solution, organization = props.organization, record = props.record, path = props.path, fieldNameForAPIName = props.fieldNameForAPIName, canonicalEndpointLabel = props.canonicalEndpointLabel, nameBasedEndpointLabel = props.nameBasedEndpointLabel, fieldLabelForNameBasedEndpoint = props.fieldLabelForNameBasedEndpoint, hideSection = props.hideSection;
    if (!(0, primeobjects_helper_util_1.isNonEmptyString)(record.shortId))
        record.shortId = (0, primeobjects_helper_util_1.newShortId)();
    var apiNameFieldHasValue = !(0, lodash_1.isNil)(fieldNameForAPIName) &&
        (0, primeobjects_helper_util_1.isNonEmptyString)(record[fieldNameForAPIName]);
    var webSlug = apiNameFieldHasValue
        ? (0, primeobjects_helper_util_1.slug)(record[fieldNameForAPIName])
        : (0, primeobjects_helper_util_1.getRecordSlug)(record);
    var nameBasedEndpoint = (_a = props.nameBasedEndpoint) !== null && _a !== void 0 ? _a : "".concat((0, exports.getOrganizationNameBasedUrl)(solution, organization)).concat(path, "/").concat(webSlug);
    var canonicalEndpoint = (_b = props.canonicalEndpoint) !== null && _b !== void 0 ? _b : "".concat((0, exports.getOrganizationCanonicalUrl)(solution, organization)).concat(path, "/").concat(record.shortId);
    return [
        !hideSection && {
            fields: [
                {
                    wrapperStyle: {
                        marginBottom: 0
                    },
                    name: "webAddressSection",
                    type: "section",
                    line: sectionLine !== null && sectionLine !== void 0 ? sectionLine : "Web addresses and endpoints"
                }
            ]
        },
        (0, primeobjects_helper_util_1.isNonEmptyString)(nameBasedEndpoint) && {
            fields: [
                {
                    name: "nameBasedEndpoint",
                    label: "Name-based web address",
                    value: nameBasedEndpointLabel !== null && nameBasedEndpointLabel !== void 0 ? nameBasedEndpointLabel : nameBasedEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: apiNameFieldHasValue
                        ? "This URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed.")
                        : "Although this URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed , all previous URLs will always work.")
                }
            ]
        },
        (0, primeobjects_helper_util_1.isNonEmptyString)(canonicalEndpoint) && {
            fields: [
                {
                    name: "canonicalEndpoint",
                    label: canonicalEndpointLabel !== null && canonicalEndpointLabel !== void 0 ? canonicalEndpointLabel : "Canonical web address",
                    value: canonicalEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: "This URL will never change."
                }
            ]
        }
    ];
};
exports.getWebAddressesRows = getWebAddressesRows;
//# sourceMappingURL=web-addresses-rows.js.map